//
//  BMICalcViewController.m
//  BMICalc
//

#import "BMICalcViewController.h"

@implementation BMICalcViewController

@synthesize heightText;
@synthesize weightText;
@synthesize calcButton;
@synthesize resetButton;
@synthesize saveButton;
@synthesize resultLabel;
@synthesize bmiStr;
@synthesize result;
@synthesize eventStore;
@synthesize adView;
@synthesize bannerIsVisible;

- (void)viewDidLoad {
    [super viewDidLoad];    
    self.view.backgroundColor = [UIColor colorWithPatternImage:[UIImage imageNamed:@"bg-green.jpg"]];
	// イベントストアを初期化
	self.eventStore = [[EKEventStore alloc] init];
	
	// 広告ビューを初期化
	self.adView = [[ADBannerView alloc] initWithFrame:CGRectZero];
	self.adView.currentContentSizeIdentifier = ADBannerContentSizeIdentifierPortrait;
	// ADBannerViewのデリゲートにこのBMICalcViewController自身を設定
	self.adView.delegate = self;
	// 画面の下部に表示
	self.adView.frame = CGRectOffset(adView.frame, 0, self.view.frame.size.height - self.adView.frame.size.height);
	
	// 広告表示フラグをYESに設定
	self.bannerIsVisible = YES;
	
	// サブビューとして追加
	[self.view addSubview:adView];
}

- (void)viewDidUnload {
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}

- (void)dealloc {
	[heightText release];
    [weightText release];
    [calcButton release];
    [resetButton release];
    [resultLabel release];
	[bmiStr release];
	[result release];
	[eventStore release];
	[adView release];
    [super dealloc];
}

// 身長・体重テキストのキーボードを隠す処理
- (void)textFieldResignFirstResponder {
    [heightText resignFirstResponder];
    [weightText resignFirstResponder];
}

// UITextFieldDelegateプロトコルで定義されているイベントメソッド
// キーボードのReturnキーが押された後に呼ばれる
- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    [self textFieldResignFirstResponder];
    return YES;
}

// BMI計算実行処理
- (IBAction)executeCalc:(id) sender {
	
	// キーボードを隠す
    [self textFieldResignFirstResponder];
	
    // 身長テキストフィールドに入力された値（cm）をメートルに変換
    float height = [heightText.text floatValue]/100;
    
	// 体重テキストフィールドに入力された値を取得
    float weight = [weightText.text intValue];
    
    // BMI = 体重（kg）÷ (身長（m） × 身長（m）)
    float bmi = weight / (height * height);
    
    // BMI計算結果（少数点第1位まで）
    self.bmiStr = [ NSString stringWithFormat: @"%.1f", bmi];
    
    // 標準体重（kg） = 身長（m） × 身長（m） × BMI標準値（22）
    float stdWeight = (height * height) * 22;
    
    // 標準体重の計算結果（少数点第1位まで）
    NSString *stdWeightStr = [ NSString stringWithFormat: @"%.1f", stdWeight ];
    
    // 結果判定を行う
	self.result = @"";
	
	// BMIが18.5より小さければ「やせ気味」
    if (bmi < 18.5) {
        self.result = NSLocalizedString(@"wei_thin", @"Message for result thin.");		
    } 
	// BMIが18.5以上、25より小さければ「理想の体重」
	else if (bmi >= 18.5 && bmi < 25) {
        self.result = NSLocalizedString(@"wei_normal", @"Message for result normal.");		
    } 
	// それ以上の場合は「肥満」
	else {
        self.result = NSLocalizedString(@"wei_fat", @"Message for result fat.");
    }
    
    // 判定結果を結果ラベルに設定
    resultLabel.text = [NSString stringWithFormat:@"%@%@%@%@%@%@",
                        @"BMI\n", bmiStr, 
                        NSLocalizedString(@"stdWeight", @"Label for Standard weight."),
						stdWeightStr, @"kg\n\n",
                        result];
}

// リセット処理
- (IBAction)executeReset:(id) sender {
	// 各値をクリア
    heightText.text = @"";
    weightText.text = @"";
    resultLabel.text = @"";
}

-(IBAction)executeSave:(id)sender {
	// 新しいカレンダーイベントを作成
    EKEvent *event  = [EKEvent eventWithEventStore:self.eventStore];
	
	// イベントのタイトルを設定
    event.title     = [NSString stringWithFormat:@"BMI:%@ %@",self.bmiStr, self.result];	
	// 開始日を設定
    event.startDate = [[NSDate alloc] init];
	// 終了日を設定
	event.endDate   = [[NSDate alloc] initWithTimeInterval:60 sinceDate:event.startDate];
	// 注釈にBMI計算結果の表示内容を設定
	event.notes = resultLabel.text;
	
	// イベントが関連付けられるカレンダーを設定
    [event setCalendar:[self.eventStore defaultCalendarForNewEvents]];

	// イベントをカレンダーデータベースに保存
    [self.eventStore saveEvent:event span:EKSpanThisEvent error: nil];
	
	resultLabel.text = [NSString stringWithFormat:@"記録しました\n%@", event.title];
}

// ADBannerViewDelegate のデリゲート処理

// 広告読み込みエラー時に実行される
- (void)bannerView:(ADBannerView *)banner didFailToReceiveAdWithError:(NSError * )error{
	// 広告が表示されていたら
	if (self.bannerIsVisible) {
		// 画面より下に広告を隠す
		self.adView.frame = CGRectOffset(adView.frame, 0, self.view.frame.size.height);
		// 広告表示フラグをYESに設定
		self.bannerIsVisible = NO;
	}
}

// 広告読み込み成功時に実行される
- (void)bannerViewDidLoadAd:(ADBannerView *)banner{
	// 広告が表示されていなかったら
	if (!self.bannerIsVisible) {
		// 画面の下部に広告表示
		self.adView.frame = CGRectOffset(adView.frame, 0, self.view.frame.size.height - self.adView.frame.size.height);
		// 広告表示フラグをYESに設定
		self.bannerIsVisible = YES;
	}
}

@end